==> dojo-1.9.4.tgz: package/cldr/nls/da/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"field-weekday": "ugedag",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"days-format-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"dateFormat-long": "d. MMMM y G",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E d/M/y G",
	"dateFormatItem-Md": "d/M",
	"field-era": "æra",
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "år",
	"field-hour": "time",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-day-relative+1": "i morgen",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"quarters-format-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-M": "M",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"timeFormat-medium": "HH.mm.ss",
	"dateFormatItem-Hm": "HH.mm",
	"quarters-standAlone-abbr": [
		"K1",
		"K2",
		"K3",
		"K4"
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "minut",
	"field-dayperiod": "dagtid",
	"days-standAlone-abbr": [
		"søn",
		"man",
		"tir",
		"ons",
		"tor",
		"fre",
		"lør"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d/M",
	"field-day": "dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "tidszone",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "sidste år",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "måned",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-MMM": "MMM",
	"dateFormat-short": "d/M/y",
	"field-second": "sekund",
	"field-month-relative+0": "denne måned",
	"field-month-relative+1": "næste måned",
	"dateFormatItem-Ed": "E 'd'. d.",
	"field-week": "uge",
	"dateFormat-medium": "d. MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "sidste uge",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "næste år",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denne uge",
	"field-week-relative+1": "næste uge"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/da/hebrew.js <==
define(
//begin v1.x content
{
	"days-standAlone-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"field-second-relative+0": "nu",
	"field-weekday": "Ugedag",
	"field-wed-relative+0": "denne onsdag",
	"field-wed-relative+1": "næste onsdag",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "E d. MMM",
	"field-tue-relative+-1": "sidste tirsdag",
	"days-format-short": [
		"sø",
		"ma",
		"ti",
		"on",
		"to",
		"fr",
		"lø"
	],
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "sidste fredag",
	"field-wed-relative+-1": "sidste onsdag",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormat-full": "EEEE d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E d/M/y G",
	"field-thu-relative+-1": "sidste torsdag",
	"dateFormatItem-Md": "d/M",
	"dayPeriods-format-wide-noon": "middag",
	"field-era": "Æra",
	"timeFormat-short": "HH.mm",
	"quarters-format-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"timeFormat-long": "HH.mm.ss z",
	"field-year": "År",
	"field-hour": "Time",
	"field-sat-relative+0": "denne lørdag",
	"field-sat-relative+1": "næste lørdag",
	"timeFormat-full": "HH.mm.ss zzzz",
	"field-day-relative+0": "i dag",
	"field-thu-relative+0": "denne torsdag",
	"field-day-relative+1": "i morgen",
	"field-thu-relative+1": "næste torsdag",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "i overmorgen",
	"quarters-format-abbr": [
		"1. kvt.",
		"2. kvt.",
		"3. kvt.",
		"4. kvt."
	],
	"quarters-standAlone-wide": [
		"1. kvartal",
		"2. kvartal",
		"3. kvartal",
		"4. kvartal"
	],
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-M": "M",
	"days-standAlone-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"dateFormatItem-yyyyMMM": "MMM y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dayPeriods-format-abbr-noon": "middag",
	"timeFormat-medium": "HH.mm.ss",
	"field-sun-relative+0": "denne søndag",
	"dateFormatItem-Hm": "HH.mm",
	"field-sun-relative+1": "næste søndag",
	"quarters-standAlone-abbr": [
		"1. kvt.",
		"2. kvt.",
		"3. kvt.",
		"4. kvt."
	],
	"eraAbbr": [
		"AM"
	],
	"field-minute": "Minut",
	"field-dayperiod": "AM/PM",
	"days-standAlone-abbr": [
		"søn",
		"man",
		"tir",
		"ons",
		"tor",
		"fre",
		"lør"
	],
	"dateFormatItem-d": "d.",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "i går",
	"field-day-relative+-2": "i forgårs",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d/M",
	"field-fri-relative+0": "denne fredag",
	"field-fri-relative+1": "næste fredag",
	"field-day": "Dag",
	"days-format-wide": [
		"søndag",
		"mandag",
		"tirsdag",
		"onsdag",
		"torsdag",
		"fredag",
		"lørdag"
	],
	"field-zone": "Tidszone",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "sidste år",
	"field-month-relative+-1": "sidste måned",
	"dateFormatItem-hm": "h.mm a",
	"days-format-abbr": [
		"søn.",
		"man.",
		"tir.",
		"ons.",
		"tor.",
		"fre.",
		"lør."
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"dateFormatItem-yyyyMd": "d/M/y G",
	"field-month": "Måned",
	"dateFormatItem-MMM": "MMM",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"O",
		"T",
		"F",
		"L"
	],
	"field-tue-relative+0": "denne tirsdag",
	"field-tue-relative+1": "næste tirsdag",
	"field-mon-relative+0": "denne mandag",
	"field-mon-relative+1": "næste mandag",
	"dateFormat-short": "d/M/y",
	"dayPeriods-format-narrow-noon": "middag",
	"field-second": "Sekund",
	"field-sat-relative+-1": "sidste lørdag",
	"field-sun-relative+-1": "sidste søndag",
	"field-month-relative+0": "denne måned",
	"field-month-relative+1": "næste måned",
	"dateFormatItem-Ed": "E 'd'. d.",
	"field-week": "Uge",
	"dateFormat-medium": "d. MMM y G",
	"field-year-relative+0": "i år",
	"field-week-relative+-1": "sidste uge",
	"dateFormatItem-yyyyM": "M/y G",
	"field-year-relative+1": "næste år",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateFormatItem-Hms": "HH.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "MMM y G",
	"field-mon-relative+-1": "sidste mandag",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "denne uge",
	"field-week-relative+1": "næste uge"
}
//end v1.x content
);
